function result=LongHgen(y,pred,control,alpha3,maxp,h);
%This function calculates the confidence interval of beta_h and its median unbiased estimate
%using Campbell and Yogo's method in the second stage
%allow for SERIAL CORRELATION

%INPUT: 
%	y is the dependent variable, pred is the regressor CONTEMPORANEOUS,
%   control is the lagged endog variable we want to clean the regression from (time as
%   in the regression) -- basically enter y lagged once
%       delta =horizon/T
%       alpha3= size of the confidence interval for beta (e.g. 0.10)
%       maxp  = max n of lags for the ADF regression
%       h = horizon 

yres=olsres(y(2:end),control(2:end)); gammatilda=olsbeta(y(2:end),[control(2:end),pred(1:end-1),ones(rows(y)-1,1)]); gammatilda=gammatilda(1,1); 
predres=olsres(pred(1:end-1),control(2:end)); 
y=yres; pred=predres; 

p=bic1(pred,maxp); 
n=rows(y);  T=n-p;     
r=y(p+1:end); x=pred(p+1:end,:);
Lx=[ones(T,1),pred(p:end-1,:)]; 
i=1; while i<=p; if i==1; Z=Lx; else; Z=[Z,pred(p-i+2:n-i+1,:)-pred(p-i+1:n-i,:)]; end; i=i+1; end; %Z=Lx; 
Dx=[pred(p+1:end,:)-pred(p:end-1,:)];

zcrit=norminv(1-alpha3/2,0,1);  

coef=olsbeta(x,Lx); v=olsres(x,Lx); Sv2=v'*v/(T-2);
varmat=Sv2*pinv(Lx'*Lx); SErho=sqrt(varmat(2,2)); 

coef=olsbeta(Dx,Z)'; e=olsres(Dx,Z); 

if p==1; psi=0; else; psi=coef(3:p+1,:); end; 

varmat1=(e'*e)/(T-p-1)*pinv(Z'*Z);
df=coef(2,1)/sqrt(varmat1(2,2));

rhogls=1-7/T;
xbar=[pred(p,:);pred(p+1:n,:)-pred(p:n-1,:).*rhogls];
inter=[1;(1-rhogls)*ones(T,1)]; 
mu=olsbeta(xbar,inter);
Zbar=Z(:,2)-mu*ones(rows(Z),1);
if p>1; Zbar=[Zbar,Z(:,3:p+1)]; end; 
coef=olsbeta(Dx,Zbar)';  
resid=Dx-Zbar*coef;
varmat=(resid'*resid)/(T-p)*pinv(Zbar'*Zbar);
dfgls=coef(1)/sqrt(varmat(1,1));

load DFGLSbelt; 
cLOW=Lconf(dfgls,DFGLSbelt,5); cUP=Uconf(dfgls,DFGLSbelt,5); 


coef=olsbeta(r,Lx); 
u=olsres(r,Lx); psi=0;
beta=coef(2); 
Sigma=([u,e]'*[u,e])./(T-2);  

delta=Sigma(1,2)/sqrt(Sigma(1,1)*Sigma(2,2));  
omega2=Sigma(2,2)/(1-sum(psi))^2;

varmat=Sigma(1,1)*pinv(Lx'*Lx);
SEbeta=sqrt(varmat(2,2));
tstat=beta/SEbeta;

load DFbelt; load tconf; load tquantL; load tquantR; 
cL=BonLconf(df,DFbelt,-abs(delta),tconf(:,1)); 
cU=BonUconf(df,DFbelt,-abs(delta),tconf(:,1)); 
critL=BonLcrit(cL,cU,-abs(delta),tquantL);

cL=BonLconf(df,DFbelt,-abs(delta),tconf(:,2)); 
cU=BonUconf(df,DFbelt,-abs(delta),tconf(:,2)); 
critR=BonRcrit(cL,cU,-abs(delta),tquantR);

if delta<=0; Cavanagh=[beta-critR*SEbeta,beta-critL*SEbeta]; 
else; Cavanagh=[beta+critL*SEbeta,beta+critR*SEbeta]; end;



load DFGLSbelt; load Qconf; 
cL=BonLconf(dfgls,DFGLSbelt,-abs(delta),Qconf(:,1)); 
cU=BonUconf(dfgls,DFGLSbelt,-abs(delta),Qconf(:,2)); 

rhoL=1+cL/T;
rhoU=1+cU/T;

correct=(T-2)/2*Sigma(1,2)/sqrt(Sigma(2,2)*omega2)*(omega2/Sv2-1)*SErho^2; 


Qbeta=zeros(1,7);
rbar=r-Sigma(1,2)/sqrt(Sigma(2,2)*omega2)*(x-rhoL*Lx(:,2));
coef=olsbeta(rbar,Lx); correct=0;
Qbeta(1,1)= (coef(2)+correct-zcrit*sqrt(1-delta^2)*SEbeta);
Qbeta(1,2)= (coef(2)+correct+zcrit*sqrt(1-delta^2)*SEbeta);

rbar=r-Sigma(1,2)/sqrt(Sigma(2,2)*omega2)*(x-rhoU*Lx(:,2));
coef=olsbeta(rbar,Lx); 
Qbeta(1,3)= (coef(2)+correct-zcrit*sqrt(1-delta^2)*SEbeta);
Qbeta(1,4)= (coef(2)+correct+zcrit*sqrt(1-delta^2)*SEbeta);

if delta<=0;
    Qbeta(1,5)=Qbeta(1,3);
    Qbeta(1,6)=Qbeta(1,2);
else;
    Qbeta(1,5)=Qbeta(1,1);
    Qbeta(1,6)=Qbeta(1,4);
end;
    
    
Qconf=[Qbeta(1,5),Qbeta(1,6)];

deltah=(h/T); 
hstock1=1; for j=1:deltah*T-1; hstock1=exp(cUP*(j/T))+hstock1; end;                        
hstock0=1; for j=1:deltah*T-1; hstock0=exp(cLOW*(j/T))+hstock0; end;                        
hstock1=hstock1./(deltah*T); hstock0=hstock0./(deltah*T); 
result=[Qbeta(1,5)*hstock0,Qbeta(1,6)*hstock1].*h*(inv(1-gammatilda)); 


