function wald = chowgmmstarhac(y,x,z,w,t,heter,hac);
%Calculates Chow* (optimal) test statistic by GMM estimation for a fixed time-break t
%y is (T*1) dependent variable
%x is (T*p) independent variable whose param are time-varying
%z is (T*q) independent variable whose param are not time-varying
%w is (T*k) vector of instruments (OLS sets w equal to x)
%if no subsets then set z=0;
%t is the time of the break (NOT as fraction of sample size) -- ie two samples are 1:t-1,t:T

if z==0;
    [T,p]=size(x); pi=t/T; [T,k]=size(w);
    y1=y(1:t,:); x1=x(1:t,:); w1=w(1:t,:);
    y2=y(t+1:T,:); x2=x(t+1:T,:); w2=w(t+1:T,:);
    X=[x1,zeros(t,p);zeros(T-t,p),x2]; W=[w1,zeros(t,k);zeros(T-t,k),w2];
    b1=gmmbeta(y1,x1,w1,heter); b2=gmmbeta(y2,x2,w2,heter); 
    e1=gmmres(y1,x1,w1,heter); e2=gmmres(y2,x2,w2,heter);
    ew1=mmult(e1,w1); ew2=mmult(e2,w2); 
    if heter==1;
        Sigma1=(w1)'*(diag(e1.^2))*(w1)/t;
        Sigma2=(w2)'*(diag(e2.^2))*(w2)/(T-t);
      if hac==1; 
        Sigma1=nw(ew1,t^(1/3)); 
        Sigma2=nw(ew2,(T-t)^(1/3)); 
      end;
    end;
    if heter==0;
        s2=(sum(e1.^2)+sum(e2.^2))/(T); 
        if hac==1;   s2=nw(e(1:T),T^(1/3)); end; 
        Sigma1=s2*w1'*w1/t; Sigma2=s2*w2'*w2/(T-t);
    end;
    Gamma=inv([pi*Sigma1,zeros(k,k);zeros(k,k),(1-pi)*Sigma2]);
    Swx1=w1'*x1/T; Swx2=w2'*x2/T;
    M=[Swx1,zeros(k,p);zeros(k,p),Swx2];
    R=[eye(p),-eye(p);pi*eye(p),(1-pi)*eye(p)];
    VRb=R*inv(M'*Gamma*M)*R'; 
    wald=T*([b1-b2;pi*b1+(1-pi)*b2])'*(inv(VRb))*([b1-b2;pi*b1+(1-pi)*b2]);
    
else;
    [T,p]=size(x); [T,q]=size(z); pi=t/T; [T,k]=size(w);
    y1=y(1:t,:); x1=x(1:t,:); z1=z(1:t,:); w1=w(1:t,:);
    y2=y(t+1:T,:); x2=x(t+1:T,:); z2=z(t+1:T,:); w2=w(t+1:T,:);
    X=[x1,zeros(t,p),z1;zeros(T-t,p),x2,z2]; W=[w1,zeros(t,k);zeros(T-t,k),w2];
    b=gmmbeta(y,X,W,heter); b1=b(1:p,:); b2=b(p+1:2*p,:);
    e=gmmres(y,X,W,heter);
    ew1=mmult(e(1:t),w1); 
    ew2=mmult(e(t+1:T),w2); 
    if heter==1;
        Sigma1=(w1)'*(diag(e(1:t).^2))*(w1)/t;
        Sigma2=(w2)'*(diag(e(t+1:T).^2))*(w2)/(T-t);
        if hac==1; Sigma1=nw(ew1,t^(1/3)); Sigma2=nw(ew2,(T-t)^(1/3)); end;
    end;

    if heter==0;
        s2=(sum(e(1:T).^2))/(T); 
        if hac==1;   s2=nw(e(1:T),T^(1/3)); end; 
        Sigma1=s2*w1'*w1/t; Sigma2=s2*w2'*w2/(T-t);
    end;
    Gamma=inv([pi*Sigma1,zeros(k,k);zeros(k,k),(1-pi)*Sigma2]);
    Swx1=w1'*x1/T; Swz1=w1'*z1/T; Swx2=w2'*x2/T; Swz2=w2'*z2/T;
    M=[Swx1,zeros(k,p),Swz1;zeros(k,p),Swx2,Swz2];
    R=[eye(p),-eye(p),zeros(p,q);pi*eye(p),(1-pi)*eye(p),zeros(p,q)];
    VRb=R*inv(M'*Gamma*M)*R'; 
    wald=T*([b1-b2;pi*b1+(1-pi)*b2])'*(inv(VRb))*([b1-b2;pi*b1+(1-pi)*b2]);
end;
