function b2 = gmmbetahac(y,z,x,heter,hac);
%Calculates variance of the coefficient vector for GMM with optimal weighting matrix (See Hayashi, chp.3)
%y is (T*1) dependent variable
%z is (T*l) independent variable
%x is (T*k) matrix of instruments
%heter is a dummy: =0 if want cond. homosked. and =1 if cond. heterosked.
%hac is a dummy: =0 if want no HAC and =1 if want HAC correction (bandwidth is T^(1/3) in Newey-West).
%we checked that if x=z then we get back to the OLS if cond homosk

%check order condition
T=length(y); qn=T^(1/3);
Sxx=x'*x/T; Sxz=x'*z/T; Sxy=x'*y/T; [a,k]=size(x); [a,l]=size(z);
if k<l; disp('order condition violated'); 
    else;
    %1st stage (2SLS)
    W1=inv(Sxx);
    b1=(inv(Sxz'*W1*Sxz))*(Sxz'*W1*Sxy);
    e=y-z*b1;
    if heter==1; S=x'*(diag(e.^2))*x./T; W2=inv(S);
    elseif heter==0; S=(Sxx)*sum(e.^2)/T; W2=inv(S); end; 
    if hac==1; 
        xe=mmult(e,x); 
        S=(nw(xe,qn)); 
        W2=inv(S);  
    end;
   
  
    %2nd stage
    b2=(inv(Sxz'*W2*Sxz))*(Sxz'*W2*Sxy);
    if heter==1; avarb=inv(Sxz'*W2*Sxz); 
    elseif heter==0; avarb=inv(Sxx)*sum((y-z*b2).^2)/T; 
    end;
    if hac==1; 
        xe=mmult((y-z*b2),x); 
        S=(nw(xe,qn)); 
        avarb=inv(Sxz'*inv(S)*Sxz);
    end;
end;