function result = testsforeccomb2RWWD(e1,p,lagged,tds,lagdep);
%This file does forecast combinations with equal weights -- 
%for pvalues use Diebold-Mariano's (note that pvalues of Clark-McCracken do not
%necessarily make sense and should be corrected -- ClarkMcCracken is based on one restriction...)!
%INPUTS:
%e1 is the Tx1 vector of variable to be forecasted
%p is the Txk matrix containing the k variables used to forecast e1
%OUTPUTS:
%2x6 vector containing DM and ENCNEW tests on the first row and their
%pvalues on the second row (in the order: split,recurs,roll) 

heter=1; %heter=1 if robust to cond heteroskedasticity; heter=0 if cond homoskedasticity is imposed
hac  =1; %hac=1 if robust to serial correlation (Newey-West with bandwidth=T^(1/3))

[T,kk]=size(p); ba0=0;

yo1_all=[]; yosplit1_all=[]; yoroll1_all=[]; yoroll1AR1_all=[];  yoroll1RWWD1_all=[];
if lagdep==0; init=2; elseif lagdep==1; init=2; end;

for js=1:cols(p); 
    p1=[p(:,js),lagged]; 
    %Oos tests for predictive ability
    R=50; round((0.5)*T); Pred=T-R; 
    yo1=zeros(T,1);rw1=zeros(T,1);true1=zeros(T,1);b0=0;yosplit1=zeros(T,1);yoroll1=zeros(T,1);
    brollvec=[]; yoroll1AR1=zeros(T,1); yoroll1RWWD1=zeros(T,1);
    for j=init:Pred;
       boos=olsbeta(e1(1:R+j-1,1),[ones(R+j-1,1),p1(1:R+j-1,:)]);
       bsplit=olsbeta(e1(1:R,1),[ones(R,1),p1(1:R,:)]);
       yo1(R+j,1)=[1,p1(R+j,:)]*boos';
       yosplit1(R+j,1)=[1,p1(R+j,:)]*bsplit';
       broll=olsbeta(e1(j:R+j-1,1),[ones(R,1),p1(j:R+j-1,:)]); 
       brollAR1=olsbeta(e1(j:R+j-1,1),[ones(R,1),e1(j-1:R+j-1-1,:)]); 
       brollRWWD1=olsbeta(e1(j:R+j-1,1),ones(R,1)); 
       yoroll1(R+j,1)=[1,p1(R+j,:)]*broll';
       yoroll1AR1(R+j,1)=[1,e1(R+j-1,:)]*brollAR1';
       yoroll1RWWD1(R+j,1)=[1]*brollRWWD1';
       rw1(R+j,1)=0;
       true1(R+j,1)=e1(R+j);
    end;
    yo1_all=[yo1_all,yo1]; yosplit1_all=[yosplit1_all,yosplit1]; yoroll1_all=[yoroll1_all,yoroll1]; 
    yoroll1AR1_all=[yoroll1AR1_all,yoroll1AR1];  yoroll1RWWD1_all=[yoroll1RWWD1_all,yoroll1RWWD1];  
end; 
yo1=mean(yo1_all,2); yosplit1=mean(yosplit1_all,2); yoroll1=mean(yoroll1_all,2);
yoroll1AR1=mean(yoroll1AR1_all,2); yoroll1RWWD1=mean(yoroll1RWWD1_all,2);

restr=1; 

%Sequential tests
yo=yo1(R+1:T,1);rw=rw1(R+1:T,1);true=true1(R+1:T,1);
u1=(true-yo).^2; u2=(true-rw).^2; f=u1-u2;
varf=cov(f)/(Pred); 
DMrecurs=media(f)/sqrt(varf);
pvDMrecurs=cdfchic(DMrecurs^2,1);
ENCNEWrecurs=nan; 
pvENCNEWrecurs=nan;

if lagdep==0;
%Rolling tests versus RWWD
yoroll=yoroll1(R+1:T,1); yorollRWWD1=yoroll1RWWD1(R+1:T,1); u1roll=(true-yoroll).^2; u2roll=(true-yorollRWWD1).^2; froll=u1roll-u2roll; 
varfroll=cov(froll)/(Pred); 
DMroll=media(froll)/sqrt(varfroll);
pvDMroll=cdfchic(DMroll^2,1);
ENCNEWroll=Pred*(media((true-yorollRWWD1).^2-(true-yoroll).*(true-yorollRWWD1)))/(media(((true-yoroll)).^2)); 
pvENCNEWroll=1; if ENCNEWroll>ooscv(restr,0.1,2,2); pvENCNEWroll=0.10; end; if ENCNEWroll>ooscv(restr,0.05,2,2); pvENCNEWroll=0.05; end; if ENCNEWroll>ooscv(restr,0.01,2,2); pvENCNEWroll=0.01; end;

figure;
plot(tds(R+1:T,:),yoroll,'+--'); hold on; plot(tds(R+1:T,:),true,'LineWidth',2); 
plot(tds(R+1:T,:),true.*0);  
legend('Forecast combination', 'Actual realization');
axis tight; xlabel('Time'); ylabel('Global commodity price change');  hold off; 

elseif lagdep==1;
%Rolling tests versus AR1
yoroll=yoroll1(R+1:T,1); yorollAR1=yoroll1AR1(R+1:T,1); u1roll=(true-yoroll).^2; u2roll=(true-yorollAR1).^2; froll=u1roll-u2roll; 
varfroll=cov(froll)/(Pred); 
DMroll=media(froll)/sqrt(varfroll);
pvDMroll=cdfchic(DMroll^2,1);
ENCNEWroll=Pred*(media((true-yorollAR1).^2-(true-yoroll).*(true-yorollAR1)))/(media(((true-yoroll)).^2));
pvENCNEWroll=1; if ENCNEWroll>ooscv(restr,0.1,2,2); pvENCNEWroll=0.10; end; if ENCNEWroll>ooscv(restr,0.05,2,2); pvENCNEWroll=0.05; end; if ENCNEWroll>ooscv(restr,0.01,2,2); pvENCNEWroll=0.01; end;
end; 

%Split tests
yosplit=yosplit1(R+1:T,1); u1split=(true-yosplit).^2; fsplit=u1split-u2;
varfsplit=cov(fsplit)/(Pred); 
DMsplit=media(fsplit)/sqrt(varfsplit);
pvDMsplit=cdfchic(DMsplit^2,1);
ENCNEWsplit=nan; 
pvENCNEWsplit=nan;  

result=[DMsplit,DMrecurs,DMroll,ENCNEWsplit,ENCNEWrecurs,ENCNEWroll; pvDMsplit,pvDMrecurs,pvDMroll,pvENCNEWsplit,pvENCNEWrecurs,pvENCNEWroll];
