function gamma = var_coeffvar(y,p,const);

%Calculates heteroskedasticity-consistent (White)
%variance of coefficients
%for an unrestricted VAR(p)
%y must have different variables as columns
%if const=1 puts a constant; if j=0 there is no constant
%Assume conditional homoskedasticity
%Contains dof correction for small samples (18-3-03)

[n k]=size(y);
u=n-p;
phi=zeros(k,k*p); if const==1; phi=zeros(k,k*p+1); end;
res=zeros(u,k); res1=zeros(u,k); ytv=y(p+1:n,:);
for j=1:k;
yt=y(p+1:n,j);
ylag=zeros(u,p*k);
for i=1:p;
   ylag(:,k*i-k+1:k*i)=y(p+1-i:n-i,:);
end;
if const==1, ylag=[ylag(:,:),ones(length(ylag),1)]; end;
coeff=((inv(ylag'*ylag))*(ylag'*yt))';
phi(j,:)=coeff; 
res1(:,j)=yt-ylag*coeff';
end;
%At=A'; res=zeros(n-p,p);
%for i=1:p;
%    res(:,i)=ytv(:,i)-ylag*At(:,i); 
%end;
%omega=res'*res/(n-p);
%sqrt((inv(ylag'*ylag))*omega(1,1))

sigma=res'*res/u; 
sigma1=res1'*res1/u; %this is correct...
sigma2=res1'*res1/(length(res1)-k*p); %every equation in the VAR has k*p regressors
gamma=inv(   (kron(eye(k),(ylag'*ylag)))*  inv((kron(sigma2,(ylag'*ylag))))  *(kron(eye(k),((ylag'*ylag))))   );

sqrt(diag(gamma)); phit=phi'; phivec=phit(:);
coeff_stderror=[phivec,sqrt(diag(gamma))]; %gives coeff. (1st col.) and their standard ERRORS (2nd col.) -- this file has been double-checked with EVIEWS
stderror=[sqrt(diag(gamma))];%gives standard ERRORS -- this file has been double-checked with EVIEWS

%phi is such that:
%phi(1,1), phi(1,2), phi(1,3),... these are regressors of y1(t) onto y1(t-1), y2(t-1), y1(t-2), y2(t-2), ..
%phi(2,1), phi(2,2), phi(2,3),... these are regressors of y2(t) onto y1(t-1), y2(t-1), y1(t-2), y2(t-2), ..
...
%phi(k,1), ... these are regressors of ykt onto y1(t-1), y2(t-1), y1(t-2), y2(t-2), ..

%phivec contains phi(1,1);phi(1,2);phi(1,3);...;(phi(2,1);phi(2,2);...

%Example of how to do tests -- double checked with EVIEWS
%t-test is such that: t-stat=phi(1)/stderror(1)
%wald is s.t.: phi(1,1)+phi(1,2)=0; R=[1,1,zeros(1,length(phivec)-2)]; r=0;
%R=[1,1,0,0]; r=1;
%(R*phivec-r)'*inv(R*gamma*R')*(R*phivec-r)